import Link from "next/link";
import { notFound, redirect } from "next/navigation";
import { ArrowLeft } from "lucide-react";

import { getClientAuthorizationStats } from "@/lib/dto/authorization";
import { prisma } from "@/lib/prisma";
import { getCurrentUser } from "@/lib/session";
import { Badge } from "@/components/ui/badge";
import { Button } from "@/components/ui/button";
import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import { EditClientForm } from "@/components/clients/edit-client";

async function getClientDetails(id: string, userId: string) {
  const client = await prisma.client.findUnique({
    where: {
      id,
      userId, // 确保只能查看自己的应用
    },
  });

  if (!client) {
    return null;
  }

  const stats = await getClientAuthorizationStats(id);

  return {
    ...client,
    stats,
  };
}

export default async function ClientDetailsPage({
  params,
}: {
  params: { id: string };
}) {
  const user = await getCurrentUser();
  if (!user?.id) {
    redirect("/sign-in");
  }

  const client = await getClientDetails(params.id, user.id);
  if (!client) {
    notFound();
  }

  return (
    <div className="mx-auto max-w-7xl px-4 py-8 sm:px-6 lg:px-8">
      <div className="mb-8 flex items-center justify-between">
        <div className="flex items-center gap-4">
          <Link href="/dashboard/clients">
            <Button variant="outline" size="icon">
              <ArrowLeft className="h-4 w-4" />
            </Button>
          </Link>
          <h1 className="text-2xl font-bold">{client.name}</h1>
          <Badge variant={client.enabled ? "default" : "destructive"}>
            {client.enabled ? "启用" : "禁用"}
          </Badge>
        </div>
      </div>

      <div className="grid gap-6 md:grid-cols-2">
        <Card>
          <CardHeader>
            <CardTitle>应用信息</CardTitle>
            <CardDescription>应用的基本信息</CardDescription>
          </CardHeader>
          <CardContent>
            <dl className="space-y-4">
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  Client ID
                </dt>
                <dd className="mt-1 font-mono">{client.clientId}</dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  Client Secret
                </dt>
                <dd className="mt-1 font-mono">{client.clientSecret}</dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  回调地址
                </dt>
                <dd className="mt-1">{client.redirectUri}</dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  应用主页
                </dt>
                <dd className="mt-1">
                  {client.home ? (
                    <a
                      href={client.home}
                      target="_blank"
                      rel="noopener noreferrer"
                      className="text-primary hover:underline"
                    >
                      {client.home}
                    </a>
                  ) : (
                    "-"
                  )}
                </dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  创建时间
                </dt>
                <dd className="mt-1">
                  {new Date(client.createdAt).toLocaleString()}
                </dd>
              </div>
            </dl>
          </CardContent>
        </Card>

        <Card>
          <CardHeader>
            <CardTitle>使用统计</CardTitle>
            <CardDescription>应用的使用情况统计</CardDescription>
          </CardHeader>
          <CardContent>
            <dl className="space-y-8">
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  总授权用户数
                </dt>
                <dd className="mt-1">
                  <div className="text-3xl font-bold">{client.stats.total}</div>
                </dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  最近30天活跃用户
                </dt>
                <dd className="mt-1">
                  <div className="text-3xl font-bold">
                    {client.stats.activeLastMonth}
                  </div>
                  <p className="text-sm text-muted-foreground">
                    占总用户的{" "}
                    {(
                      (client.stats.activeLastMonth / client.stats.total) *
                        100 || 0
                    ).toFixed(1)}
                    %
                  </p>
                </dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  最近30天新增用户
                </dt>
                <dd className="mt-1">
                  <div className="text-3xl font-bold">
                    {client.stats.newLastMonth}
                  </div>
                  <p className="text-sm text-muted-foreground">
                    环比增长{" "}
                    {(
                      (client.stats.newLastMonth / client.stats.total) * 100 ||
                      0
                    ).toFixed(1)}
                    %
                  </p>
                </dd>
              </div>
            </dl>
          </CardContent>
        </Card>

        <Card className="md:col-span-2">
          <CardHeader>
            <CardTitle>最近授权</CardTitle>
            <CardDescription>显示最近授权的用户</CardDescription>
          </CardHeader>
          <CardContent>
            <div className="space-y-4">
              {client.stats.recentAuthorizations.map((auth) => (
                <div
                  key={auth.id}
                  className="flex items-center justify-between border-b pb-4 last:border-0 last:pb-0"
                >
                  <div className="space-y-1">
                    <p className="text-sm text-muted-foreground">
                      用户于 {new Date(auth.createdAt).toLocaleString()} 授权
                    </p>
                    <p className="text-sm text-muted-foreground">
                      最后使用于{" "}
                      {auth.lastUsedAt
                        ? new Date(auth.lastUsedAt).toLocaleString()
                        : "从未使用"}
                    </p>
                  </div>
                  <Badge variant={auth.enabled ? "default" : "destructive"}>
                    {auth.enabled ? "已授权" : "已禁用"}
                  </Badge>
                </div>
              ))}
            </div>
          </CardContent>
        </Card>

        <Card className="md:col-span-2">
          <CardHeader>
            <CardTitle>应用设置</CardTitle>
            <CardDescription>编辑应用的基本信息</CardDescription>
          </CardHeader>
          <CardContent>
            <EditClientForm client={client} />
          </CardContent>
        </Card>
      </div>
    </div>
  );
}
