import { redirect } from "next/navigation";

import { getClientByClientId } from "@/lib/dto/client";
import { getCurrentUser } from "@/lib/session";
import { Authorizing } from "@/components/auth/authorizing";
import { ErrorCard } from "@/components/auth/error-card";

export interface AuthorizeParams {
  scope?: string;
  response_type: string;
  client_id: string;
  redirect_uri: string;
  state?: string;
}

export default async function OAuthAuthorization({
  searchParams,
}: {
  searchParams: AuthorizeParams;
}) {
  // 检查用户是否已登录
  const user = await getCurrentUser();
  if (!user?.id) {
    // 构建当前 URL 作为回调地址
    const currentUrl = new URL(
      "/oauth/authorize",
      process.env.NEXT_PUBLIC_HOST_URL,
    );
    Object.entries(searchParams).forEach(([key, value]) => {
      if (value) currentUrl.searchParams.append(key, value.toString());
    });
    redirect(
      `/sign-in?callbackUrl=${encodeURIComponent(currentUrl.toString())}`,
    );
  }

  // 验证必要的参数
  if (
    !searchParams.response_type ||
    !searchParams.client_id ||
    !searchParams.redirect_uri
  ) {
    return (
      <div className="flex min-h-screen items-center justify-center p-4">
        <ErrorCard
          title="参数错误"
          description="缺少必要的参数"
          redirectUri={searchParams.redirect_uri}
          error="invalid_request"
          errorDescription="缺少必要的参数"
        />
      </div>
    );
  }

  // 验证 response_type
  if (searchParams.response_type !== "code") {
    return (
      <div className="flex min-h-screen items-center justify-center p-4">
        <ErrorCard
          title="参数错误"
          description="不支持的授权类型"
          redirectUri={searchParams.redirect_uri}
          error="unsupported_response_type"
          errorDescription="仅支持 code 授权类型"
        />
      </div>
    );
  }

  // 验证客户端
  const client = await getClientByClientId(searchParams.client_id);
  if (!client) {
    return (
      <div className="flex min-h-screen items-center justify-center p-4">
        <ErrorCard
          title="应用不存在"
          description="您尝试访问的应用不存在或已被删除"
          redirectUri={searchParams.redirect_uri}
          error="invalid_client"
          errorDescription="应用不存在"
        />
      </div>
    );
  }

  // 检查应用是否被禁用
  if (!client.enabled) {
    return (
      <div className="flex min-h-screen items-center justify-center p-4">
        <ErrorCard
          title="应用已禁用"
          description="此应用已被管理员禁用，暂时无法使用"
          redirectUri={searchParams.redirect_uri}
          error="access_denied"
          errorDescription="此应用已被禁用"
        />
      </div>
    );
  }

  // 检查回调地址是否匹配
  if (client.redirectUri !== searchParams.redirect_uri) {
    return (
      <div className="flex min-h-screen items-center justify-center p-4">
        <ErrorCard
          title="回调地址不匹配"
          description="应用提供的回调地址与注册时不符"
          redirectUri={searchParams.redirect_uri}
          error="invalid_request"
          errorDescription="回调地址不匹配"
        />
      </div>
    );
  }

  // 使用原始的 Authorizing 组件处理授权流程
  return (
    <div className="flex min-h-screen items-center justify-center bg-gray-50 p-4">
      <Authorizing />
    </div>
  );
}
